@@ -20,8 +20,9 @@ This base class is NOT directly instantiable.
 
 =cut
 
-use Digest::SHA1 ();
+use Digest::SHA ();
 use HTTP::Headers::Util ();
+use Module::Load ();
 
 use Net::WebSocket::HTTP ();
 use Net::WebSocket::X ();
@@ -51,8 +52,6 @@ connection.
 =item * C<extensions> - A list of extension objects that the Handshake
 object will interact with to determine extension support.
 
-=back
-
 =head1 COMMON EXTENSION INTERFACE
 
 Each object in the C<extensions> array must implement the following methods:
@@ -72,7 +71,7 @@ value from its C<ok_to_use()> method.
 
 =item * C<ok_to_use()> A boolean that indicates whether the peer indicates
 proper support for the extension. This should not be called until after
-C<consume_parameters()>.
+C<consume_parameters().
 
 =back
 
@@ -104,15 +103,20 @@ sub get_subprotocol {
     return $self->{'_subprotocol'};
 }
 
+#sub get_match_extensions {
+#    my $self = shift;
+#
+#    Call::Context::must_be_list();
+#
+#    return { %{ $self->{'_match_extensions'} } };
+#}
+
 =head2 I<OBJ>->consume_headers( HDR1 => VAL1, HDR2 => VAL2, .. )
 
 The “workhorse” method of this base class. Takes in the HTTP headers
 and verifies that the look as they should, setting this object’s own
 internals as appropriate.
 
-This will throw an appropriate exception if any header is missing
-or otherwise invalid.
-
 =cut
 
 sub consume_headers {
@@ -121,11 +125,10 @@ sub consume_headers {
     $self->{'_no_use_legacy'} = 1;
 
     while ( my ($k => $v) = splice( @kv_pairs, 0, 2 ) ) {
-        next if !defined $v;
         $self->_consume_peer_header($k => $v);
     }
 
-    $self->_die_if_missing_headers();
+    $self->_valid_headers_or_die();
 
     return;
 }
@@ -200,7 +203,7 @@ sub _get_accept {
 
     $key_b64 =~ s<\A\s+|\s+\z><>g;
 
-    my $accept = Digest::SHA1::sha1_base64( $key_b64 . _WS_MAGIC_CONSTANT() );
+    my $accept = Digest::SHA::sha1_base64( $key_b64 . _WS_MAGIC_CONSTANT() );
 
     #pad base64
     $accept .= '=' x (4 - (length($accept) % 4));
@@ -268,7 +271,7 @@ sub _missing_generic_headers {
 sub _consume_sec_websocket_extensions_header {
     my ($self, $value) = @_;
 
-    require Net::WebSocket::Handshake::Extension;
+    Module::Load::load('Net::WebSocket::Handshake::Extension');
 
     for my $xtn ( Net::WebSocket::Handshake::Extension->parse_string($value) ) {
         my $xtn_token = $xtn->token();
@@ -300,10 +303,6 @@ sub _consume_generic_header {
                 $self->{'_connection_header_ok'} = 1;
             }
         }
-
-        if (!$self->{'_connection_header_ok'}) {
-            die Net::WebSocket::X->create('BadHeader', 'Connection' => $value, 'Must contain “upgrade”');
-        }
     }
     elsif ($hname eq 'upgrade') {
         $value =~ tr<A-Z><a-z>;
@@ -312,10 +311,6 @@ sub _consume_generic_header {
                 $self->{'_upgrade_header_ok'} = 1;
             }
         }
-
-        if (!$self->{'_upgrade_header_ok'}) {
-            die Net::WebSocket::X->create('BadHeader', 'Upgrade' => $value, 'Must contain “websocket”');
-        }
     }
     elsif ($hname eq 'sec-websocket-protocol') {
         for my $token ( Net::WebSocket::HTTP::split_tokens($value) ) {
